function successRate = computeSuccess( testSet, testLabels,  distanceMetric, population)

global meanMatrix meanStdDev meanAbsDev covMat clusterCenters clusterSizes nets svmArray fuzzyIndeces trainingSet trainingLabels

load bounds.txt

utr = unique(trainingLabels);
utr = utr(1:population, :);
limitedTestSet = testSet(testLabels <= max(utr), :);
limitedTestLabels = testLabels(testLabels <= max(utr), :);

errorsum = 0;
for i=1:size(limitedTestSet, 1) % for every test sample
    unknownFeatureVector = limitedTestSet(i, :);

    realsubject = limitedTestLabels(i);
    
    distanceVector = inf(51,1);
  
    for s=1:population
        subject = utr(s);
        meanFeatureVector = meanMatrix(subject, :);

        userTrainingSet = trainingSet(find(trainingLabels == subject), :);
        stdDev = meanStdDev(subject,:);

        if distanceMetric == 1
            distanceElement = pdist( [unknownFeatureVector; meanFeatureVector] );
        elseif distanceMetric == 2
            distanceElement = pdist( [unknownFeatureVector; meanFeatureVector] ) / sqrt( norm(unknownFeatureVector) * norm(meanFeatureVector) );
        elseif distanceMetric == 3 || distanceMetric == 4
            distanceElement = pdist([unknownFeatureVector; meanFeatureVector], 'cityblock');
        elseif distanceMetric == 5
            meanAbsDevVector = meanAbsDev(subject, :);
            distanceElement = manhattan_scaled(unknownFeatureVector, meanFeatureVector, meanAbsDevVector);
        elseif distanceMetric == 6 || distanceMetric == 7 % mahalonobis
            s = (subject - 1) * 31 + 1;
            e = subject * 31;
            userCovarianceMatrix = covMat(s:e, :);
            %         if distanceMetric == 6
            %             distanceElement = mahalonobis(unknownFeatureVector, meanFeatureVector, userCovarianceMatrix);
            %         else
            %             distanceElement = mahalonobis_normed(unknownFeatureVector, meanFeatureVector, userCovarianceMatrix);
            %         end

            if distanceMetric == 6
                distanceElement = mahalanobis(unknownFeatureVector, meanFeatureVector, userCovarianceMatrix);
            else
                distanceElement = power(mahalanobis(unknownFeatureVector, meanFeatureVector, userCovarianceMatrix), 2) / norm(unknownFeatureVector) * norm(meanFeatureVector) ;
            end
        elseif distanceMetric == 8 % nearest negihbor - mahalonobis
            s = (subject - 1) * 31 + 1;
            e = subject * 31;
            userCovarianceMatrix = covMat(s:e, :);
            distanceElement = Inf;
            for i=1:size(userTrainingSet, 1)
                newDist = mahalanobis(unknownFeatureVector, userTrainingSet(i,:), userCovarianceMatrix);
                if newDist < distanceElement
                    distanceElement = newDist;
                end % if
            end % for
        elseif distanceMetric == 9 % backpropagation neural network
            net = nets{subject};
            tmp = sim(net, unknownFeatureVector');
            distanceElement = 1 - tmp;
            tmp1 = tmp;
        elseif distanceMetric == 10     % auto-assoc neural network
            net = nets{subject};
            tmp = sim(net, unknownFeatureVector');
            distanceElement = pdist( [unknownFeatureVector; tmp'] );
        elseif distanceMetric == 11
            userFuzzyIndeces = fuzzyIndeces(subject, :);
            fuzzyMembers = fuzzyfeatures(unknownFeatureVector, bounds);
            distanceElement = sum(ceil(abs(fuzzyMembers - userFuzzyIndeces) / 1000 ));
        elseif distanceMetric == 12 % outlier counting
            distanceElement = z_score(unknownFeatureVector, meanFeatureVector, stdDev);
        elseif distanceMetric == 13 % svm
             svmObject = svmArray{subject};
             kernel='gaussian';
             kerneloption=1;
             ypred = svmoneclassval(unknownFeatureVector, svmObject.xsup, svmObject.alpha, svmObject.rho, kernel,kerneloption);    
             distanceElement = (-1) * ypred;            
        elseif distanceMetric == 14 % knearest Neighbor
            s = (subject - 1) * 3 + 1;
            e = subject * 3;
            userClusterCenters = clusterCenters(s:e,:);
            userClusterSizes = clusterSizes(s:e,:);
            distanceElement = nearestNeighbor(unknownFeatureVector, userClusterCenters, userClusterSizes);
        else
            distanceElement = -9999;
        end
        
        distanceVector(subject) = distanceElement;                 
        
    end

    [minval ind] = min(distanceVector);
    predictedSubject = ind;

    if predictedSubject ~= realsubject
        errorsum = errorsum + 1;
    end
    
end

errorRate = errorsum / size(limitedTestSet, 1);
successRate = (1 - errorRate) * 100;


